===============
Sample Document
===============

Renders a go diagram.  This will take an ascii go diagram and return
an image node which points to the new image
   
Looks like:
  
.. go:: go_diagrams/output.png

    $$ -----------
    $$ | . . . . .
    $$ | . . O . .
    $$ | . X O . .
    $$ | . X X . .
    $$ | . . . . .

Until I get the image rendering working, it will just render straight 
ascii.
